"use strict";

exports.__esModule = true;
exports.trackFeatureIsUsed = trackFeatureIsUsed;
exports.trackCli = trackCli;
exports.trackError = trackError;
exports.trackBuildError = trackBuildError;
exports.setDefaultTags = setDefaultTags;
exports.decorateEvent = decorateEvent;
exports.setTelemetryEnabled = setTelemetryEnabled;
exports.startBackgroundUpdate = startBackgroundUpdate;
exports.isTrackingEnabled = isTrackingEnabled;
exports.aggregateStats = aggregateStats;
exports.addSiteMeasurement = addSiteMeasurement;
exports.expressMiddleware = expressMiddleware;
exports.setDefaultComponentId = setDefaultComponentId;
exports.setGatsbyCliVersion = setGatsbyCliVersion;

var _telemetry = require("./telemetry");

var _createFlush = require("./create-flush");

const instance = new _telemetry.AnalyticsTracker();
const flush = (0, _createFlush.createFlush)(instance.isTrackingEnabled());
process.on(`exit`, flush); // For long running commands we want to occasionally flush the data
//
// The data is also sent on exit.

const intervalDuration = process.env.TELEMETRY_BUFFER_INTERVAL;
const interval = intervalDuration && Number.isFinite(+intervalDuration) ? Math.max(Number(intervalDuration), 1000) : 10 * 60 * 1000; // 10 min

function tick() {
  flush().catch(console.error).then(() => setTimeout(tick, interval));
}

function trackFeatureIsUsed(name) {
  instance.trackFeatureIsUsed(name);
}

function trackCli(input, tags, opts) {
  instance.captureEvent(input, tags, opts);
}

function trackError(input, tags) {
  instance.captureError(input, tags);
}

function trackBuildError(input, tags) {
  instance.captureBuildError(input, tags);
}

function setDefaultTags(tags) {
  instance.decorateAll(tags);
}

function decorateEvent(event, tags) {
  instance.decorateNextEvent(event, tags);
}

function setTelemetryEnabled(enabled) {
  instance.setTelemetryEnabled(enabled);
}

function startBackgroundUpdate() {
  setTimeout(tick, interval);
}

function isTrackingEnabled() {
  return instance.isTrackingEnabled();
}

function aggregateStats(data) {
  return instance.aggregateStats(data);
}

function addSiteMeasurement(event, obj) {
  instance.addSiteMeasurement(event, obj);
}

function expressMiddleware(source) {
  return function (_req, _res, next) {
    try {
      instance.trackActivity(`${source}_ACTIVE`);
    } catch (e) {// ignore
    }

    next();
  };
} // Internal


function setDefaultComponentId(componentId) {
  instance.componentId = componentId;
}

function setGatsbyCliVersion(version) {
  instance.gatsbyCliVersion = version;
}

module.exports = {
  trackFeatureIsUsed,
  trackCli,
  trackError,
  trackBuildError,
  setDefaultTags,
  decorateEvent,
  setTelemetryEnabled,
  startBackgroundUpdate,
  isTrackingEnabled,
  aggregateStats,
  addSiteMeasurement,
  expressMiddleware
};